@@ -17,7 +17,7 @@ no warnings;			# XXX
 
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(assemble_fh newasm endasm assemble asm maxopix maxsvix);
-$VERSION = '0.07_03';
+$VERSION = '0.07_04';
 
 use strict;
 my %opnumber;
@@ -219,6 +219,11 @@ sub gen_header {
     $header .= B::Asmdata::PUT_U32($Config{ptrsize});
     $header .= B::Asmdata::PUT_U32($Config{longsize});
     $header .= B::Asmdata::PUT_strconst('"'.$Config{byteorder}.'"');
+    if ($version gt "0.06_04") {
+      my $archflag = 0;
+      $archflag += 1 if $Config{useithreads};
+      $header .= B::Asmdata::PUT_U16($archflag);
+    }
     $header;
 }
 
